@@ -33,7 +33,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     let real_input = include_str!("day11_input.txt");
     test_part_one!(real_input => 650);
     test_part_two!(real_input => 1465);
